<?php
namespace ElegantAddons\Widgets;

use ElegantAddons\Helper_Functions;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Control_Select;
use Elementor\Group_Control_Background;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Eae_Comparisontable extends Widget_Base {

    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = Includes\premium_Template_Tags::getInstance();
    }

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'comparison-table';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */

    public function get_title() {
        return __( 'Comparison Table', 'elegant-addons-for-elementor' );
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-divider';
    }

    public function get_style_depends() {
        return [
            'elegant-addons-css'
        ];
    }

     /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'elegant-addons' ];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'eae_ct_header_content_section',
            [
                'label' => __( 'Header Content', 'elegant-addons-for-elementor' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'eae_ct_show_header',
            [
                'label'        => __( 'Show Header', 'elegant-addons-for-elementor' ),
                'type'         => Controls_Manager::SWITCHER,
                'separator'    => 'before',
            ]
        );

        $this->add_control(
            'eae_ct_column_one',
            [
                'label'     => __( 'Column 1', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'Features',
            ]
        );

        $this->add_control(
            'eae_ct_column_two',
            [
                'label'     => __( 'Column 2', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'Free',
            ]
        );
        $this->add_control(
            'eae_ct_column_three',
            [
                'label'     => __( 'Column 3', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'Pro',
            ]
        );
        $this->add_control(
            'eae_ct_category_name',
            [
                'label' => __( 'Category Name', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'Basic',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'eae_ct_content_section',
            [
                'label' => __( 'Table Content', 'elegant-addons-for-elementor' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'eae_ct_list_title', [
                'label' => __( 'Title', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'List Title' , 'elegant-addons-for-elementor' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'eae_ct_list_content', [
                'label' => __( 'Content', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
                'default' => __( 'List Content' , 'elegant-addons-for-elementor' ),
                'show_label' => false,
            ]
        );



        $repeater->add_control(
            'eae_ct_columntwo_content', [
                'label' => __( 'Column 2', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'List Title' , 'elegant-addons-for-elementor' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'eae_ct_columntwo_icon',
            [
                'label' => __( 'Icons', 'plugin-domain' ),
                'type' => \Elementor\Controls_Manager::ICON,
                'default' => 'fa fa-check',
            ]
        );

        $repeater->add_control(
            'eae_ct_columntwo_icon_color',
            [
                'label' => __( 'Color', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .column-two-icon.fa' => 'color: {{VALUE}}',
                ],

            ]
        );

        $repeater->add_control(
            'eae_ct_columnthree_content', [
                'label' => __( 'Column 3', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'List Title' , 'elegant-addons-for-elementor' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'eae_ct_columnthree_icon',
            [
                'label' => __( 'Icons', 'plugin-domain' ),
                'type' => \Elementor\Controls_Manager::ICON,
                'default' => 'fa fa-check',
            ]
        );

        $repeater->add_control(
            'eae_ct_columnthree_icon_color',
            [
                'label' => __( 'Color', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .column-three-icon.fa' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'eae_ct_table_content_list',
            [
                'label' => __( 'Repeater List', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'eae_ct_list_title' => __( 'Title #1', 'elegant-addons-for-elementor' ),
                        'eae_ct_list_content' => __( 'Item content. Click the edit button to change this text.', 'elegant-addons-for-elementor' ),
                    ],
                    [
                        'eae_ct_list_title' => __( 'Title #2', 'elegant-addons-for-elementor' ),
                        'eae_ct_list_content' => __( 'Item content. Click the edit button to change this text.', 'elegant-addons-for-elementor' ),
                    ],
                ],
                'title_field' => '{{{ eae_ct_list_title }}}',
            ]
        );
        $this->add_control(
            'eae_ct_show_footer',
            [
                'label'        => __( 'Show Footer', 'elegant-addons-for-elementor' ),
                'type'         => Controls_Manager::SWITCHER,
                'separator'    => 'before',
            ]
        );

        $this->add_control(
            'eae_ct_download_text', [
                'label' => __( 'Download Text', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Download' , 'elegant-addons-for-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'eae_ct_download_link',
            [
                'label' => __( 'Link', 'plugin-domain' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->add_control(
            'eae_ct_buy_text', [
                'label' => __( 'Buy Now Text', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Buy Now' , 'elegant-addons-for-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'eae_ct_buy_link',
            [
                'label' => __( 'Link', 'plugin-domain' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'eae_ct_section_style',
            [
                'label'      => __( 'Header', 'elegant-addons-for-elementor' ),
                'tab'        => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'eae_ct_header_pro_bg',
            [
                'label'     => __( 'Pro Background Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table th.comparison-table-pro' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'eae_ct_header_pro_text',
            [
                'label'     => __( 'Pro Text Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table th.comparison-table-pro' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'eae_ct_header_pro_typography',
                'selector' => '{{WRAPPER}} .eae-ct-container .comparison-table th.comparison-table-pro',
            ]
        );
        $this->add_control(
            'eae_ct_header_free_bg',
            [
                'label'     => __( 'Free Background Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table th.comparison-table-free' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'eae_ct_header_free_text',
            [
                'label'     => __( 'Free Text Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table th.comparison-table-free' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'eae_ct_header_free_typography',
                'selector' => '{{WRAPPER}} .eae-ct-container .comparison-table tr.comparison-table-section-header',
            ]
        );
        $this->add_control(
            'eae_ct_header_category_bg',
            [
                'label'     => __( 'Category Background Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table .comparison-table-section-header td' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'eae_ct_header_category_text',
            [
                'label'     => __( 'Category Text Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table .comparison-table-section-header td' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'eae_ct_header_category_typography',
                'selector' => '{{WRAPPER}} .eae-ct-container .comparison-table .comparison-table-section-header td',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'eae_ct_content_section_style',
            [
                'label'      => __( 'Table Content', 'elegant-addons-for-elementor' ),
                'tab'        => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'eae_ct_table_content_title',
            [
                'label'     => __( 'Title Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table .comparison-table-heading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'eae_ct_table_content_titletypography',
                'selector' => '{{WRAPPER}} .eae-ct-container .comparison-table .comparison-table-heading',
            ]
        );

        $this->add_control(
            'eae_ct_table_dese_color',
            [
                'label'     => __( 'Title Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table .comparison-table-desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'eae_ct_table_content_dese_typography',
                'selector' => '{{WRAPPER}} .eae-ct-container .comparison-table .comparison-table-desc',
            ]
        );

        $this->add_control(
            'eae_ct_table_heading_hover_color',
            [
                'label'     => __( 'Text Hover Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comparison-table-row:hover td span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'eae_ct_table_text_hover_color',
            [
                'label'     => __( 'Background Hover Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .eae-ct-container .comparison-table tr.comparison-table-row:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="eae-ct-container">
        <table class="comparison-table">
            <?php if( $settings[ 'eae_ct_show_header' ]  == 'yes' ) : ?>
              <tr>
                <th class="empty-cell comparison-table-tfeatures"><?php echo esc_html( $settings['eae_ct_column_one'] ); ?></th>
                <th class="comparison-table-free eae-center-td"><?php echo esc_html( $settings['eae_ct_column_two'] ); ?></th>
                <th class="comparison-table-pro eae-center-td"><?php echo esc_html( $settings['eae_ct_column_three'] ); ?></th>
              </tr>
            <?php endif; ?>
            <?php if( $settings[ 'eae_ct_category_name' ]  != '' ) : ?>
              <tr class="comparison-table-section-header">
                <td colspan="3"><?php echo esc_html( $settings['eae_ct_category_name'] ); ?></td>
              </tr>
            <?php endif; ?>
            <?php foreach (  $settings['eae_ct_table_content_list'] as $item ) { ?>
              <tr class="comparison-table-row elementor-repeater-item-<?php echo $item['_id']; ?>">
                <td class="comparison-table-heading"><?php echo esc_html( $item['eae_ct_list_title'] ); ?>
                    <?php if( $item[ 'eae_ct_list_content' ]  != '' ) : ?>
                        <br>
                        <span class="comparison-table-desc"><?php echo esc_html( $item['eae_ct_list_content'] ); ?></span>
                    <?php endif; ?>
                  </td>
                <td class="eae-center-td">
                    <?php if( $item['eae_ct_columntwo_content'] == '' ) {
                        echo'<i class="column-two-icon ' . $item['eae_ct_columntwo_icon'] . '" aria-hidden="true"></i>';
                    } else { ?>
                        <span><?php echo $item['eae_ct_columntwo_content']; ?></span>
                    <?php } ?>
                </td>
                <td class="eae-center-td">
                    <?php if( $item['eae_ct_columnthree_content'] == '' ) {
                        echo'<i class="column-three-icon ' . $item['eae_ct_columnthree_icon'] . '" aria-hidden="true"></i>';
                    } else { ?>
                        <span><?php echo $item['eae_ct_columnthree_content']; ?></span>
                    <?php } ?>
                </td>
              </tr>
            <?php } //End Foreach ?>
        <?php if( $settings[ 'eae_ct_show_footer' ]  == 'yes' ) : ?>
          <tr class="comparison-table-footer">
            <td></td>
            <td class="comparison-table-free">
            <?php
                $target = $settings['eae_ct_download_link']['is_external'] ? ' target="_blank"' : '';
                $nofollow = $settings['eae_ct_download_link']['nofollow'] ? ' rel="nofollow"' : '';
                echo '<a href="' . esc_url( $settings['eae_ct_download_link']['url'] ) . '"' . $target . $nofollow . ' class="eae-ct-download-link">' . $settings['eae_ct_download_text'] . '</a>';
            ?>
            </td>
            <td class="comparison-table-pro">
            <?php
                $buy_target      = $settings['eae_ct_buy_link']['is_external'] ? ' target="_blank"' : '';
                $buy_nofollow    = $settings['eae_ct_buy_link']['nofollow'] ? ' rel="nofollow"' : '';
                echo '<a href="' . esc_url( $settings['eae_ct_buy_link']['url'] ) . '"' . $buy_target . $buy_nofollow . ' class="eae-ct-buy-link">' . $settings['eae_ct_buy_text'] . '</a>';
            ?>
          </tr>
        <?php endif; ?>
        </table>
        </div><!-- /.eae-ct-container -->
    <?php
    }

    /**
     * Render the widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _content_template() {
        ?>
        <div class="eae-ct-container">
        <table class="comparison-table">
        <# if ( settings.eae_ct_show_header == 'yes' ) { #>
          <tr>
            <th class="empty-cell comparison-table-tfeatures">{{ settings.eae_ct_column_one }}</th>
            <th class="comparison-table-free eae-center-td">{{ settings.eae_ct_column_two }}</th>
            <th class="comparison-table-pro eae-center-td">{{ settings.eae_ct_column_three }}</th>
          </tr>
        <# } #>
        <# if ( settings.eae_ct_category_name != '' ) { #>
          <tr class="comparison-table-section-header">
            <td colspan="3">{{ settings.eae_ct_category_name }}</td>
          </tr>
        <# } #>
            <# _.each( settings.eae_ct_table_content_list, function( item ) { #>
              <tr class="comparison-table-row elementor-repeater-item-{{ item._id }}">
                <td class="comparison-table-heading">
                    {{ item.eae_ct_list_title }}
                    <# if ( item.eae_ct_list_content != '' ) { #>
                        <br>
                        <span class="comparison-table-desc">{{ item.eae_ct_list_content }}</span>
                    <# } #>
                </td>
                <td class="eae-center-td">
                    <# if( item.eae_ct_columntwo_content == '' ) { #>
                        <i class="column-two-icon {{ item.eae_ct_columntwo_icon }}"></i>
                    <# } else { #>
                        <span>{{{ item.eae_ct_columntwo_content }}}</span>
                    <# } #>
                </td>
                <td class="eae-center-td">
                    <# if( item.eae_ct_columnthree_content == '' ) { #>
                        <i class="column-three-icon {{ item.eae_ct_columnthree_icon }}"></i>
                    <# } else { #>
                        <span>{{{ item.eae_ct_columnthree_content }}}</span>
                    <# } #>
                </td>
              </tr>
            <# }); #>
        <# if ( settings.eae_ct_show_footer == 'yes' ) { #>
          <tr class="comparison-table-footer">
            <td></td>
            <td class="comparison-table-free">
            <#
                var target          = settings.eae_ct_download_link.is_external ? ' target="_blank"' : '';
                var nofollow        = settings.eae_ct_download_link.nofollow ? ' rel="nofollow"' : '';
            #>
                <a href="{{settings.eae_ct_download_link.url}}" {{ target }} {{ nofollow }} class="eae-ct-download-link">{{settings.eae_ct_download_text}}</a>
            </td>
            <td class="comparison-table-pro">
            <#
                var buy_target       = settings.eae_ct_buy_link.is_external ? ' target="_blank"' : '';
                var buy_nofollow     = settings.eae_ct_buy_link.nofollow ? ' rel="nofollow"' : '';
            #>
                <a href="{{settings.eae_ct_buy_link.url}}" {{ buy_target }} {{ buy_nofollow }} class="eae-ct-buy-link">{{settings.eae_ct_buy_text}}</a>
            </td>
          </tr>
        <# } #>
        </table>
        </div><!-- /.eae-ct-container -->
        <?php
    }
}
