<?php
namespace ElegantAddons\Widgets;


use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Background;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Eae_Countdown extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'eae-countdown';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */

    public function get_title() {
        return __( 'EAE Countdown', 'elegant-addons-for-elementor' );
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-countdown';
    }
    public function get_script_depends() {
        return [ 'eae-scripts', 'eae-countdown' ];
    }

    public function get_style_depends() {
        return [
            'elegant-addons-css'
        ];
    }

     /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'elegant-addons' ];
    }


    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls() {
        // Time Section Start
        $this->start_controls_section(
            '_section_time',
            [
                'label' => __('Time', 'elegant-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'due_date',
            [
                'label' => __('Time', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::DATE_TIME,
                'default' => date("Y-m-d", strtotime("+ 1 day")),
                'description' => esc_html__('Set the due date and time', 'elegant-addons-for-elementor'),
            ]
        );
        $this->add_control(
            'show_days',
            array(
                'label'        => esc_html__( 'Days', 'elegant-addons-for-elementor' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'elegant-addons-for-elementor' ),
                'label_off'    => esc_html__( 'Hide', 'elegant-addons-for-elementor' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            )
        );

        $this->add_control(
            'label_days',
            array(
                'label'       => esc_html__( 'Days Label', 'elegant-addons-for-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Days', 'elegant-addons-for-elementor' ),
                'placeholder' => esc_html__( 'Days', 'elegant-addons-for-elementor' ),
                'condition'   => array(
                    'show_days'      => 'yes',
                ),
            )
        );

        $this->add_control(
            'show_hours',
            array(
                'label'        => esc_html__( 'Hours', 'elegant-addons-for-elementor' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'elegant-addons-for-elementor' ),
                'label_off'    => esc_html__( 'Hide', 'elegant-addons-for-elementor' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            )
        );

        $this->add_control(
            'label_hours',
            array(
                'label'       => esc_html__( 'Hours Label', 'elegant-addons-for-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Hours', 'elegant-addons-for-elementor' ),
                'placeholder' => esc_html__( 'Hours', 'elegant-addons-for-elementor' ),
                'condition'   => array(
                    'show_hours'      => 'yes',
                ),
            )
        );

        $this->add_control(
            'show_min',
            array(
                'label'        => esc_html__( 'Minutes', 'elegant-addons-for-elementor' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'elegant-addons-for-elementor' ),
                'label_off'    => esc_html__( 'Hide', 'elegant-addons-for-elementor' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            )
        );

        $this->add_control(
            'label_min',
            array(
                'label'       => esc_html__( 'Minutes Label', 'elegant-addons-for-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Minutes', 'elegant-addons-for-elementor' ),
                'placeholder' => esc_html__( 'Minutes', 'elegant-addons-for-elementor' ),
                'condition'   => array(
                    'show_min'      => 'yes',
                ),
            )
        );

        $this->add_control(
            'show_seconds',
            array(
                'label'        => esc_html__( 'Seconds', 'elegant-addons-for-elementor' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'elegant-addons-for-elementor' ),
                'label_off'    => esc_html__( 'Hide', 'elegant-addons-for-elementor' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            )
        );

        $this->add_control(
            'label_seconds',
            array(
                'label'       => esc_html__( 'Seconds Label', 'elegant-addons-for-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Seconds', 'elegant-addons-for-elementor' ),
                'placeholder' => esc_html__( 'Seconds', 'elegant-addons-for-elementor' ),
                'condition'   => array(
                    'show_seconds'      => 'yes',
                ),
            )
        );

        $this->add_control(
            'blocks_sep',
            array(
                'label'       => esc_html__( 'Blocks Separator', 'elegant-addons-for-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'placeholder' => ':',
            )
        );
        $this->end_controls_section();

        // End Action Section Start
        $this->start_controls_section(
            '_section_end_action',
            [
                'label' => __('End Action', 'elegant-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'end_action_type',
            [
                'label' => esc_html__('End Action Type', 'elegant-addons-for-elementor'),
                'label_block' => false,
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Choose which action you want to at the end of countdown.', 'elegant-addons-for-elementor'),
                'options' => [
                    'none' => esc_html__('None', 'elegant-addons-for-elementor'),
                    'message' => esc_html__('Message', 'elegant-addons-for-elementor'),
                    'url' => esc_html__('Redirection Link', 'elegant-addons-for-elementor'),
                    'img' => esc_html__('Image', 'elegant-addons-for-elementor'),
                ],
                'default' => 'none'
            ]
        );

        $this->add_control(
            'eae_countdown_end_message',
            [
                'label' => __('Countdown End Message', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::WYSIWYG,
                'default' => __('Countdown End!', 'elegant-addons-for-elementor'),
                'placeholder' => __('Type your message here', 'elegant-addons-for-elementor'),
                'condition' => [
                    'end_action_type' => 'message'
                ],
            ]
        );
        $this->add_control(
            'end_redirect_link',
            [
                'label' => __('Redirection Link', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __('https://happyaddons.com/', 'elegant-addons-for-elementor'),
                'condition' => [
                    'end_action_type' => 'url'
                ],
            ]
        );

        $this->add_control(
            'end_image',
            [
                'label' => __('Image', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    //'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'end_action_type' => 'img'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'end_image_size',
                'default' => 'large',
                'separator' => 'none',
                'condition' => [
                    'end_action_type' => 'img'
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_item_styles',
            array(
                'label'      => esc_html__( 'Item', 'elegant-addons-for-elementor' ),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            )
        );

        $this->add_responsive_control(
            'items_size_val',
            array(
                'label'      => esc_html__( 'Width', 'elegant-addons-for-elementor' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => array( 'px', '%', 'em' ),
                'default'    => array(
                    'unit' => 'px',
                    'size' => 110,
                ),
                'range'      => array(
                    'px' => array(
                        'min' => 1,
                        'max' => 600,
                    ),
                    'em' => array(
                        'min' => 1,
                        'max' => 20,
                    ),
                ),

                'selectors' => array(
                    '{{WRAPPER}} .ct-countdown-item '  => 'width: {{SIZE}}{{UNIT}};',
                ),
            )
        );

        $this->add_responsive_control(
            'items_width_val',
            array(
                'label'      => esc_html__( 'Height', 'elegant-addons-for-elementor' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => array( 'px', '%', 'em' ),
                'default'    => array(
                    'unit' => 'px',
                    'size' => 110,
                ),
                'range'      => array(
                    'px' => array(
                        'min' => 1,
                        'max' => 600,
                    ),
                    'em' => array(
                        'min' => 1,
                        'max' => 20,
                    ),
                ),


                'selectors' => array(
                    '{{WRAPPER}} .ct-countdown-item'  => 'height: {{SIZE}}{{UNIT}};',
                ),
            )
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            array(
                'name'     => 'item_bg',
                'selector' => '{{WRAPPER}} .ct-countdown-item' ,
            )
        );

        $this->add_responsive_control(
            'item_padding',
            array(
                'label'      => esc_html__( 'Item Padding', 'elegant-addons-for-elementor' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => array( 'px', '%', 'em' ),
                'selectors'  => array(
                    '{{WRAPPER}} .ct-countdown-item'   => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            )
        );

        $this->add_responsive_control(
            'item_margin',
            array(
                'label'      => esc_html__( 'Item Margin', 'elegant-addons-for-elementor' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => array( 'px', '%', 'em' ),
                'selectors'  => array(
                    '{{WRAPPER}} .ct-countdown-item'   => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            )
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            array(
                'name'        => 'border',
                'placeholder' => '1px',
                'fields_options' => array(
                    'border' => array(
                        'default' => 'solid',
                    ),
                    'width' => array(
                        'default' => array(
                            'top'      => '1',
                            'right'    => '1',
                            'bottom'   => '1',
                            'left'     => '1',
                            'isLinked' => true,
                        ),
                    ),
                    'color' => array(
                        'scheme' => array(
                            'type'  => Scheme_Color::get_type(),
                            'value' => Scheme_Color::COLOR_3,
                        ),
                    ),
                ),
                'selector'    => '{{WRAPPER}} .ct-countdown-item' ,
            )
        );

        $this->add_control(
            'item_border_radius',
            array(
                'label'      => esc_html__( 'Border Radius', 'elegant-addons-for-elementor' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => array( 'px', '%' ),
                'selectors'  => array(
                    '{{WRAPPER}} .ct-countdown-item'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            )
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            array(
                'name' => 'item_box_shadow',
                'selector' => '{{WRAPPER}} .ct-countdown-item' ,
            )
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_days_style',
            [
                'label' => __('Days', 'elegant-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'days_bg',
                'label' => __('Background', 'elegant-addons-for-elementor'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-days',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'days_border',
                'label' => __('Box Border', 'elegant-addons-for-elementor'),
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-days',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'days_time_color',
            [
                'label' => __('Time Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-days .ct-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'days_time_typography',
                'label' => __('Time Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => ['']
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-days .ct-countdown-time',
            ]
        );
        $this->add_control(
            'days_label_color',
            [
                'label' => __('Label Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-days .ct-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'days_label_typography',
                'label' => __('Label Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-days .ct-countdown-label',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            '_section_hours_style',
            [
                'label' => __('Hours', 'elegant-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'hours_bg',
                'label' => __('Background', 'elegant-addons-for-elementor'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-hours',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'hours_border',
                'label' => __('Box Border', 'elegant-addons-for-elementor'),
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-hours',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'hours_time_color',
            [
                'label' => __('Time Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-hours .ct-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'hours_time_typography',
                'label' => __('Time Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => ['']
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-hours .ct-countdown-time',
            ]
        );
        $this->add_control(
            'hours_label_color',
            [
                'label' => __('Label Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-hours .ct-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'hours_label_typography',
                'label' => __('Label Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-hours .ct-countdown-label',
            ]
        );
        $this->end_controls_section();

        //minutes style section
        $this->start_controls_section(
            '_section_minutes_style',
            [
                'label' => __('Minute', 'elegant-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'minutes_bg',
                'label' => __('Background', 'elegant-addons-for-elementor'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-minutes',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'minutes_border',
                'label' => __('Box Border', 'elegant-addons-for-elementor'),
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-minutes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'minutes_time_color',
            [
                'label' => __('Time Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-minutes .ct-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'minutes_time_typography',
                'label' => __('Time Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => ['']
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-minutes .ct-countdown-time',
            ]
        );
        $this->add_control(
            'minutes_label_color',
            [
                'label' => __('Label Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-minutes .ct-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'minutes_label_typography',
                'label' => __('Label Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-minutes .ct-countdown-label',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            '_section_seconds_style',
            [
                'label' => __('Seconds', 'elegant-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'seconds_bg',
                'label' => __('Background', 'elegant-addons-for-elementor'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-seconds',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'seconds_border',
                'label' => __('Box Border', 'elegant-addons-for-elementor'),
                'selector' => '{{WRAPPER}} .ct-countdown-item.ct-countdown-item-seconds',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'seconds_time_color',
            [
                'label' => __('Time Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-seconds .ct-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'seconds_time_typography',
                'label' => __('Time Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => ['']
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-seconds .ct-countdown-time',
            ]
        );
        $this->add_control(
            'seconds_label_color',
            [
                'label' => __('Label Color', 'elegant-addons-for-elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ct-countdown-item-seconds .ct-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'seconds_label_typography',
                'label' => __('Label Typography', 'elegant-addons-for-elementor'),
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
                'exclude' => [
                    'line_height'
                ],
                'default' => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .ct-countdown-item-seconds .ct-countdown-label',
            ]
        );
        $this->end_controls_section();


    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $due_date = date("M d Y G:i:s", strtotime($settings['due_date']));
        $this->add_render_attribute('countdown', 'class', 'countdown');
        $this->add_render_attribute('countdown', 'data-date', esc_attr($due_date));

        $this->add_render_attribute('days', 'class', 'ct-countdown-item ct-countdown-item-days');
        $this->add_render_attribute('hours', 'class', 'ct-countdown-item ct-countdown-item-hours');
        $this->add_render_attribute('minutes', 'class', 'ct-countdown-item ct-countdown-item-minutes');
        $this->add_render_attribute('seconds', 'class', 'ct-countdown-item ct-countdown-item-seconds');

        ?>
        <div class="ct-countdown-wrap">
            <div <?php $this->print_render_attribute_string('countdown'); ?>>
                <?php if( $settings['show_days'] == 'yes' ) : ?>
                    <div <?php $this->print_render_attribute_string("days"); ?>>
                        <span cless="ct-countdown-time" data-days>0</span><span class="ct-countdown-label"><?php echo esc_html( $settings['label_days'] ); ?></span>
                    </div><!-- /.ct-countdown-item ct-countdown-item-days -->
                <?php endif; ?>
                <?php if( $settings['show_hours'] == 'yes' ) : ?>
                <div <?php $this->print_render_attribute_string("hours"); ?>>
                    <span cless="ct-countdown-time" data-hours>0</span><span class="ct-countdown-label"><?php echo esc_html( $settings['label_hours'] ); ?></span>
                </div><!-- /.ct-countdown-item ct-countdown-item-hours -->
                <div class="ct-countdown-timer_separator">:</div>
                 <?php endif; ?>
                <?php if( $settings['show_min'] == 'yes' ) : ?>
                <div <?php $this->print_render_attribute_string("minutes"); ?>>
                    <span cless="ct-countdown-time" data-minutes>0</span><span class="ct-countdown-label"><?php echo esc_html( $settings['label_min'] ); ?></span>
                </div><!-- /.ct-countdown-item ct-countdown-item-minutes -->
                <?php endif; ?>
                <?php if( $settings['show_seconds'] == 'yes' ) : ?>
                <div <?php $this->print_render_attribute_string("seconds"); ?>>
                    <span cless="ct-countdown-time" data-seconds>0</span><span class="ct-countdown-label"><?php echo esc_html( $settings['label_seconds'] ); ?></span>
                </div><!-- /.ct-countdown-item ct-countdown-item-seconds -->
                <?php endif; ?>
            </div>
        </div><!-- /.ct-countdown-wrap -->

        <!--End action markup-->
        <?php
            echo '<div class="#countdown-option-end">' . wpautop(wp_kses_post($settings['eae_countdown_end_message'])) . '</div>';
            ?>
        <?php
    }
}
