<?php
namespace ElegantAddons\Widgets;

use ElegantAddons\Helper_Functions;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Control_Select;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Eae_Pricing extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'eae_pricing';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'EAE Pricing Table', 'elegant-addons-for-elementor' );
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-price-table';
    }

    public function get_style_depends() {
        return [
            'elegant-addons-css'
        ];
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'elegant-addons' ];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'ct_pricing_content_section',
            [
                'label' => __( 'Content', 'elegant-addons-for-elementor' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'ct_pricing_package_name',
            [
                'label'     => __( 'Package Name', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'PACKAGE',
            ]
        );

        $this->add_control(
            'ct_pricing_unit',
            [
                'label' => __( 'Price Unit', 'elegant-addons-for-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'default'   => '$',
            ]
        );


        $this->add_control(
            'ct_pricing_price',
            [
                'label'     => __( 'Price', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::NUMBER,
                'min'       => 0,
                'max'       => 999999,
                'step'      => 5,
                'default'   => 49,
            ]
        );

        $this->add_control(
            'ct_pricing_prefix_position',
            [
                'label'     => __( 'Prefix Position', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'left',
                'options'   => [
                    'right'     => __( 'Right', 'elegant-addons-for-elementor' ),
                    'left'      => __( 'Left', 'elegant-addons-for-elementor' ),
                ],
            ]
        );

        $this->add_control(
            'ct_pricing_scheme',
            [
                'label'     => __( 'Scheme', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'Monthly',
            ]
        );


        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'ct_pricing_features_list_title', [
                'label'         => __( 'Title', 'elegant-addons-for-elementor' ),
                'type'          => Controls_Manager::TEXT,
                'default'       => __( 'List Title' , 'elegant-addons-for-elementor' ),
                'label_block'   => true,
            ]
        );

        $repeater->add_control(
            'ct_pricing_features_list_title_color',
            [
                'label'     => __( 'Title Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}'
                ],
            ]
        );

        $repeater->add_control(
            'ct_pricing_features_icon',
            [
                'label'         => __( 'Icon', 'elegant-addons-for-elementor' ),
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-star',
                    'library'   => 'solid',
                ],
            ]
        );

        $repeater->add_control(
            'ct_pricing_features_icon_color',
            [
                'label'     => __( 'Icon Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#656565',
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}; -webkit-text-fill-color: {{VALUE}}; background-image: none;'
                ],
            ]
        );

        $this->add_control(
            'ct_pricing_features_list',
            [
                'label'     => __( 'Features List', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::REPEATER,
                'fields'    => $repeater->get_controls(),
                'default'   => [
                    [
                        'ct_pricing_features_list_title' => __( 'List item #1', 'elegant-addons-for-elementor' ),
                    ],

                    [
                        'ct_pricing_features_list_title' => __( 'List item #2', 'elegant-addons-for-elementor' ),
                    ],

                    [
                        'ct_pricing_features_list_title' => __( 'List item #3', 'elegant-addons-for-elementor' ),
                    ],
                ],
                'title_field' => '{{{ ct_pricing_features_list_title }}}',
            ]
        );

        $this->add_control(
            'ct_pricing_table_featured',
            [
                'label'         => __( 'Make This Table Featured', 'elegant-addons-for-elementor' ),
                'type'          => Controls_Manager::SWITCHER,
                'label_on'      => __( 'Show', 'elegant-addons-for-elementor' ),
                'label_off'     => __( 'Hide', 'elegant-addons-for-elementor' ),
                'return_value'  => 'yes',
                'default'       => 'no',
            ]
        );

        $this->add_control(
            'ct_pricing_featured_tag_text',
            [
                'label' => __( 'Featured Text', 'elegant-addons-for-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'default'       => 'Popular',

                'condition' => [
                   'ct_pricing_table_featured' => 'yes',
                ],

            ]
        );

        $this->end_controls_section();

        ct_button_control_content( $this );
        ct_button_control_style( $this );

        ct_fancy_divider_content_controls( $this );

        $this->start_controls_section(
            'section_style',
            [
                'label' => __( 'Style', 'elegant-addons-for-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'ct_pricing_text_align',
            [
                'label' => __( 'Alignment', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'elegant-addons-for-elementor' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'elegant-addons-for-elementor' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'elegant-addons-for-elementor' ),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'toggle' => true,
            ]
        );

        $this->add_control(
            'ct_pricing_full_bg_color',
            [
                'label'     => __( 'Background Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-table' => 'background-color: {{VALUE}}'
                ],
                'default'      => '#fff'
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'ct_pricing_section_border',
                'selector' => '{{WRAPPER}} .pricing-table',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'ct_pricing_section_border_radius',
            [
                'label' => __( 'Border Radius', 'elegant-addons-for-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pricing-table' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'ct_pricing_section_button_box_shadow',
                'selector' => '{{WRAPPER}} .pricing-table',
            ]
        );

        $this->add_responsive_control(
            'ct_pricing_section_margin',
            [
                'label' => __( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pricing-table' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'ct_pricing_section_padding',
            [
                'label' => __( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pricing-table .price-tag' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} 0 {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .pricing-table .price-details' => 'padding: 0 {{RIGHT}}{{UNIT}} 0 {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .buy-button' => 'padding: 0 {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                                'top' => '20',
                                'right' => '20',
                                'bottom' => '20',
                                'left' => '20',
                                'isLinked' => true,
                                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'ct_pricing_featured_tag_style_section',
            [
                'label' => __( 'Featured Tag', 'elegant-addons-for-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                   'ct_pricing_table_featured' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'ct_pricing_featured_tag_text_color',
            [
                'label'     => __( 'Featured Tag Text Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .card-ribbon span' => 'color: {{VALUE}}'
                ],
                'default'      => '#656565',
                'condition' => [
                   'ct_pricing_table_featured' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'ct_pricing_featured_tag_bg_color',
            [
                'label'     => __( 'Featured Tag Background Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .card-ribbon span' => 'background-color: {{VALUE}}'
                ],
                'default'      => '#fff',
                'condition' => [
                   'ct_pricing_table_featured' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ct_pricing_featured_typography',
                'label' => __( 'Typography', 'elegant-addons-for-elementor' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .card-ribbon span',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'ct_pricing_price_section_style',
            [
                'label'     => __( 'Pricing Section', 'elegant-addons-for-elementor' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

         $this->add_control(
            'ct_pricing_price_text_color',
            [
                'label'     => __( 'Price Text Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-quote .value' => 'color: {{VALUE}}'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ct-pricing_price_typography',
                'label' => __( 'Typography', 'elegant-addons-for-elementor' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .price-quote .value',
            ]
        );

        $this->add_control(
            'ct_pricing_currency_color',
            [
                'label'     => __( 'Currency Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-quote .currency' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ct-pricing-currency_typography',
                'label' => __( 'Typography', 'elegant-addons-for-elementor' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .price-quote .currency',
            ]
        );

        $this->add_control(
            'ct_pricing_scheme_color',
            [
                'label'     => __( 'Scheme Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-quote .scheme' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ct-pricing-scheme_typography',
                'label' => __( 'Scheme Typography', 'elegant-addons-for-elementor' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .price-quote .currency',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'              => 'ct_pricing_bg_color',
                'types'             => [ 'classic', 'gradient' ],
                'separator' => 'before',
                'selector'          => '{{WRAPPER}} .price-tag',
            ]
        );

        $this->add_responsive_control(
            'ct_pricing_price_section_padding',
            [
                'label' => __( 'Padding', 'elegant-addons-for-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .price-quote' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                                'top' => '0',
                                'right' => '0',
                                'bottom' => '40',
                                'left' => '0',
                                'isLinked' => false,
                            ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'ct_pricing_package_section',
            [
                'label'     => __( 'Package Section', 'elegant-addons-for-elementor' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'ct_pricing_package_title_color',
            [
                'label'     => __( 'Package Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .package-button' => 'color: {{VALUE}}'
                ],
                'default'      => '#656565',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ct_pricing_package_typography',
                'label' => __( 'Typography', 'elegant-addons-for-elementor' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .pricing-table .package-button',
            ]
        );

         $this->add_control(
            'ct_pricing_package_bg_color',
            [
                'label'     => __( 'Package Background Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .package-button' => 'background-color: {{VALUE}}'
                ],
                'default'      => '#fff',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'package_button_box_shadow',
                'selector' => '{{WRAPPER}} .package-button',
            ]
        );

        $this->add_control(
            'ct_pricing_package_border_radius',
            [
                'label' => __( 'Border Radius', 'elegant-addons-for-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .package-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

         $this->add_responsive_control(
            'ct_pricing_package_padding',
            [
                'label' => __( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pricing-table .package-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'ct_pricing_list_style',
            [
                'label'     => __( 'List Section', 'elegant-addons-for-elementor' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'ct_pricing_list_text_align',
            [
                'label' => __( 'Alignment', 'elegant-addons-for-elementor' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'elegant-addons-for-elementor' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'elegant-addons-for-elementor' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'elegant-addons-for-elementor' ),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'toggle' => true,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ct_pricing_text_typography',
                'label' => __( 'Typography', 'elegant-addons-for-elementor' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .price-details span, {{WRAPPER}} .pricing-table .price-details ul li',
            ]
        );

        $this->add_control(
            'ct_pricing_title_color',
            [
                'label'     => __( 'Text Color', 'elegant-addons-for-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-details span' => 'color: {{VALUE}}'
                ],
                'default'      => '#656565',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'              => 'ct_pricing_icons_color',
                'types'             => [ 'classic', 'gradient' ],
                'exclude'           => [ 'image' ],
                'selector'          => '{{WRAPPER}} .price-details i',
                'fields_options' => [
                  'background' => [
                    'label' => _x( 'Icon Color', 'Background Control', 'elegant-addons-for-elementor' ),
                  ],
                ]
            ]
        );

        $this->add_control(
            'ct_pricing_gutter_spacing',
            [
                'label' => __( 'Gutter Spacing (px)', 'elegant-addons-for-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .price-details i' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'ct_pricing_list_section_margin',
            [
                'label' => __( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .price-holder' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before',
                'default' => [
                                'top' => '40',
                                'right' => '0',
                                'bottom' => '20',
                                'left' => '0',
                                'isLinked' => false,
                            ],
            ]
        );

        $this->end_controls_section();

        ct_fancy_divider_style_controls( $this, 'ct_divider_style', 'fancy_divider' );
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>

        <div class="pricing-table" style="text-align: <?php echo esc_attr( $settings[ 'ct_pricing_text_align' ] ); ?>">
            <div class="price-tag">
                <?php if ( $settings['ct_pricing_table_featured'] ) : ?>
                    <div class="card-ribbon">
                        <span><?php echo esc_html( $settings['ct_pricing_featured_tag_text'] ); ?></span>
                    </div><!-- /.card-ribbon -->
                <?php endif ?>

                <div class="price-quote" style="text-align: <?php echo esc_attr( $settings[ 'ct_pricing_text_align' ] ); ?>">
                    <?php if ( $settings['ct_pricing_unit'] && ( $settings['ct_pricing_prefix_position'] == 'left' ) ) : ?>
                        <span class="currency"><?php echo esc_html( $settings['ct_pricing_unit'] ); ?></span>
                    <?php endif ?>

                    <?php if ( $settings['ct_pricing_price'] ) : ?>
                        <span class="value"><?php echo esc_html( $settings['ct_pricing_price'] ); ?></span>
                    <?php endif ?>

                    <?php if ( $settings['ct_pricing_unit'] && ( $settings['ct_pricing_prefix_position'] == 'right' ) ) : ?>
                        <span class="currency"><?php echo esc_html( $settings['ct_pricing_unit'] ); ?></span>
                    <?php endif ?>

                    <?php if ( $settings['ct_pricing_scheme'] ) : ?>
                        <p class="scheme"><?php echo esc_html( $settings['ct_pricing_scheme'] ); ?></p>
                    <?php endif ?>
                </div><!-- /.price-quote -->

                <?php if ( $settings['ct_pricing_package_name'] ) : ?>
                    <span class="package-button"><?php echo esc_html( $settings['ct_pricing_package_name'] ); ?></span>
                <?php endif ?>
            </div><!-- /.price-tag -->

            <div class="price-details" style="text-align: <?php echo esc_attr( $settings[ 'ct_pricing_list_text_align' ] ); ?>">
                <div class="price-holder">
                    <ul>
                        <?php foreach (  $settings['ct_pricing_features_list'] as $item ) { ?>
                            <?php
                                $custom_icon_color = '';
                                if ( $item['ct_pricing_features_icon_color'] != '' ) {
                                    $custom_icon_color = 'style="color: ' . esc_attr( $item['ct_pricing_features_icon_color'] ) . '; -webkit-text-fill-color: ' . esc_attr( $item['ct_pricing_features_icon_color'] ) . '; background-image: none;"';
                                }

                                $custom_title_color = '';
                                if ( $item['ct_pricing_features_list_title_color'] != '' ) {
                                    $custom_title_color = 'style="color: ' . esc_attr( $item['ct_pricing_features_list_title_color'] ) . '"';
                                }
                            ?>
                            <li><i <?php echo $custom_icon_color; ?> class="<?php echo esc_attr( $item['ct_pricing_features_icon']['value'] ); ?>"></i><span <?php echo $custom_title_color; ?>><?php echo esc_html( $item['ct_pricing_features_list_title'] ); ?></span></li>
                        <?php } //End Foreach ?>
                    </ul>
                </div><!-- /.price-holder -->
            </div><!-- /.price-details -->
            <?php ct_button_render( $this ); ?>
            <?php ct_fancy_divider_render( $this ); ?>
        </div><!-- /.pricing-table -->
        <?php
    }

    /**
     * Render the widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _content_template() {
        ?>

        <div class="pricing-table" style="text-align: {{ settings.ct_pricing_text_align }}">
            <div class="price-tag">
                <# if( settings.ct_pricing_table_featured ) { #>
                    <div class="card-ribbon">
                        <span>{{ settings.ct_pricing_featured_tag_text }}</span>
                    </div><!-- /.card-ribbon -->
                <# } #>

                <div class="price-quote" style="text-align: {{ settings.ct_pricing_text_align }}">
                    <# if( settings.ct_pricing_unit != '' && ( settings.ct_pricing_prefix_position == 'left' ) ) { #>
                        <span class="currency">{{settings.ct_pricing_unit}}</span>
                    <# } #>

                    <# if( settings.ct_pricing_price != '' ) { #>
                        <span class="value">{{settings.ct_pricing_price}}</span>
                    <# } #>

                    <# if( settings.ct_pricing_unit != '' && ( settings.ct_pricing_prefix_position == 'right' ) ) { #>
                        <span class="currency">{{settings.ct_pricing_unit}}</span>
                    <# } #>

                    <# if( settings.ct_pricing_scheme != '' ) { #>
                        <p class="scheme">{{settings.ct_pricing_scheme}}</p>
                    <# } #>
                </div><!-- /.price-quote -->

                <# if( settings.ct_pricing_package_name != '' ) { #>
                <span class="package-button">{{settings.ct_pricing_package_name}}</span>
                <# } #>
            </div><!-- /.price-tag -->

            <div class="price-details" style="text-align: {{ settings.ct_pricing_list_text_align }}">
                <div class="price-holder">
                    <ul>
                        <# _.each( settings.ct_pricing_features_list, function( item ) { #>
                            <#
                                var custom_icon_color = '';
                                if( item.ct_pricing_features_icon_color != '' ) {
                                    var custom_icon_color = 'style="color: ' + item.ct_pricing_features_icon_color + '; ; -webkit-text-fill-color: ' + item.ct_pricing_features_icon_color + '; background-image: none;"';
                                }

                                 var custom_title_color = '';
                                if( item.ct_pricing_features_list_title_color != '' ) {
                                    var custom_title_color = 'style="color: ' + item.ct_pricing_features_list_title_color + '"';
                                }
                            #>
                            <li><i {{{ custom_icon_color }}} class="{{{ item.ct_pricing_features_icon.value }}}"></i><span {{{ custom_title_color }}}>{{ item.ct_pricing_features_list_title }}</span></li>
                        <# }); #>
                    </ul>
                </div><!-- /.price-holder -->
            </div><!-- /.price-details -->
            <?php ct_button_template(); ?>
            <?php ct_fancy_divider_content_template(); ?>
        </div><!-- /.pricing-table -->

        <?php
    }
}
